@@ -147,6 +147,7 @@ def create_cluster(aws_access_key_id, aws_secret_access_key, reservation_size, i
     try:
         # Create the EC2 cluster
         print 'Launching cluster...'
+        start_time = time.time()
         try:
             reservation = conn.run_instances(image, 
                                              min_count=reservation_size, 
@@ -160,24 +161,35 @@ def create_cluster(aws_access_key_id, aws_secret_access_key, reservation_size, i
 
         # Sleep so Amazon recognizes the new instance
         print 'Waiting for EC2 cluster to instantiate...'
-        time.sleep(10)
-        for instance in reservation.instances:
+        time.sleep(15)
+        print '    Nodes that have been allocated by EC2:'
+        for i, instance in enumerate(reservation.instances):
             while not instance.update() == 'running':
                 time.sleep(3)
+            print '        Node %s' % (i)
+        print
+
         print "Cluster booted successfully!"
+        end_time = int(time.time() - start_time)
+        print '    Elapsed Time: %s minutes %s seconds' % (end_time / 60, end_time % 60)
         print
 
         # Tag the instances in this reservation
         for instance in reservation.instances:
             conn.create_tags([instance.id], {'Name': tag, 'Initializer': 'DataStax'})
-    except:
+    except Exception, err:
         print "\n\nERROR: Tags were never applied to started instances!!! Make sure you TERMINATE instances here:"
         print "    https://console.aws.amazon.com/ec2/home?region=us-east-1#s=Instances\n"
         
         # Ensure the user acknowledges pricing danger
-        while raw_input('Acknowledge warning [Type OK]: ').lower() != 'ok':
-            pass
-        raise
+        while True:
+            try:
+                while raw_input('Acknowledge warning [Type OK]: ').lower() != 'ok':
+                    pass
+                raise err
+            except KeyboardInterrupt:
+                print
+                pass
 
     # Collect ip addresses
     private_ips = []
